import { IgcGridComponent as Component } from 'igniteui-webcomponents-grids/grids/index.js';
import type { IgcGridComponentEventMap } from 'igniteui-webcomponents-grids/grids/index.js';
import { type EventName } from '../react-props.js';
/**
 * Grid provides a way to present and manipulate tabular data.
 * @fires dataPreLoad - Emitted when a new chunk of data is loaded from virtualization.
 * @fires groupingExpressionsChange - Emitted when grouping is performed.
 * @fires groupingExpansionStateChange - Emitted when groups are expanded/collapsed.
 * @fires groupingDone - Emitted when columns are grouped/ungrouped.
 * @fires filteringExpressionsTreeChange - Emitted after filtering is performed.
 * @fires advancedFilteringExpressionsTreeChange - Emitted after advanced filtering is performed.
 * @fires gridScroll - Emitted when grid is scrolled horizontally/vertically.
 * @fires cellClick - Emitted when a cell is clicked.
 * @fires rowClick - Emitted when a row is clicked.
 * @fires formGroupCreated - Emitted when formGroup is created on edit of row/cell.
 * @fires validationStatusChange - Emitted when grid's validation status changes.
 * @fires selected - Emitted when a cell is selected.
 * @fires rowSelectionChanging - Emitted when `IgxGridRowComponent` is selected.
 * @fires columnSelectionChanging - Emitted when `IgxColumnComponent` is selected.
 * @fires columnPin - Emitted before `IgxColumnComponent` is pinned.
 * @fires columnPinned - Emitted after `IgxColumnComponent` is pinned.
 * @fires cellEditEnter - Emitted when cell enters edit mode.
 * @fires cellEditExit - Emitted when cell exits edit mode.
 * @fires cellEdit - Emitted when cell has been edited.
 * @fires cellEditDone - Emitted after cell has been edited and editing has been committed.
 * @fires rowEditEnter - Emitted when a row enters edit mode.
 * @fires rowEdit - Emitted when exiting edit mode for a row.
 * @fires rowEditDone - Emitted after exiting edit mode for a row and editing has been committed.
 * @fires rowEditExit - Emitted when row editing is canceled.
 * @fires columnInit - Emitted when a column is initialized.
 * @fires columnsAutogenerated -
 * @fires sorting - Emitted before sorting expressions are applied.
 * @fires sortingDone - Emitted after sorting is completed.
 * @fires filtering - Emitted before filtering expressions are applied.
 * @fires filteringDone - Emitted after filtering is performed through the UI.
 * @fires rowAdded - Emitted when a row is added.
 * @fires rowDeleted - Emitted when a row is deleted.
 * @fires rowDelete - Emmited when deleting a row.
 * @fires rowAdd - Emmited just before the newly added row is commited.
 * @fires columnResized - Emitted after column is resized.
 * @fires contextMenu - Emitted when a cell or row is right clicked.
 * @fires doubleClick - Emitted when a cell is double clicked.
 * @fires columnVisibilityChanging - Emitted before column visibility is changed.
 * @fires columnVisibilityChanged - Emitted after column visibility is changed.
 * @fires columnMovingStart - Emitted when column moving starts.
 * @fires columnMoving - Emitted during the column moving operation.
 * @fires columnMovingEnd - Emitted when column moving ends.
 * @fires gridKeydown - Emitted when keydown is triggered over element inside grid's body.
 * @fires rowDragStart - Emitted when start dragging a row.
 * @fires rowDragEnd - Emitted when dropping a row.
 * @fires gridCopy - Emitted when a copy operation is executed.
 * @fires expansionStatesChange - Emitted when the rows are expanded or collapsed.
 * @fires selectedRowsChange - Emitted when the rows are selected or deselected.
 * @fires rowToggle - Emitted when the expanded state of a row gets changed.
 * @fires rowPinning - Emitted when the pinned state of a row is changed.
 * @fires rowPinned - Emitted when the pinned state of a row is changed.
 * @fires activeNodeChange - Emitted when the active node is changed.
 * @fires sortingExpressionsChange - Emitted before sorting is performed.
 * @fires toolbarExporting - Emitted when an export process is initiated by the user.
 * @fires rangeSelected - Emitted when making a range selection.
 * @fires rendered - Emitted after the ngAfterViewInit hook. At this point the grid exists in the DOM
 * @fires dataChanging - Emitted before the grid's data view is changed because of a data operation, rebinding, etc.
 * @fires dataChanged - Emitted after the grid's data view is changed because of a data operation, rebinding, etc.
 */
export declare const IgrGrid: import("../react-props.js").ReactWebComponent<Component, {
    onDataPreLoad: EventName<IgcGridComponentEventMap["dataPreLoad"]>;
    onGroupingExpressionsChange: EventName<IgcGridComponentEventMap["groupingExpressionsChange"]>;
    onGroupingExpansionStateChange: EventName<IgcGridComponentEventMap["groupingExpansionStateChange"]>;
    onGroupingDone: EventName<IgcGridComponentEventMap["groupingDone"]>;
    onFilteringExpressionsTreeChange: EventName<IgcGridComponentEventMap["filteringExpressionsTreeChange"]>;
    onAdvancedFilteringExpressionsTreeChange: EventName<IgcGridComponentEventMap["advancedFilteringExpressionsTreeChange"]>;
    onGridScroll: EventName<IgcGridComponentEventMap["gridScroll"]>;
    onCellClick: EventName<IgcGridComponentEventMap["cellClick"]>;
    onRowClick: EventName<IgcGridComponentEventMap["rowClick"]>;
    onFormGroupCreated: EventName<IgcGridComponentEventMap["formGroupCreated"]>;
    onValidationStatusChange: EventName<IgcGridComponentEventMap["validationStatusChange"]>;
    onSelected: EventName<IgcGridComponentEventMap["selected"]>;
    onRowSelectionChanging: EventName<IgcGridComponentEventMap["rowSelectionChanging"]>;
    onColumnSelectionChanging: EventName<IgcGridComponentEventMap["columnSelectionChanging"]>;
    onColumnPin: EventName<IgcGridComponentEventMap["columnPin"]>;
    onColumnPinned: EventName<IgcGridComponentEventMap["columnPinned"]>;
    onCellEditEnter: EventName<IgcGridComponentEventMap["cellEditEnter"]>;
    onCellEditExit: EventName<IgcGridComponentEventMap["cellEditExit"]>;
    onCellEdit: EventName<IgcGridComponentEventMap["cellEdit"]>;
    onCellEditDone: EventName<IgcGridComponentEventMap["cellEditDone"]>;
    onRowEditEnter: EventName<IgcGridComponentEventMap["rowEditEnter"]>;
    onRowEdit: EventName<IgcGridComponentEventMap["rowEdit"]>;
    onRowEditDone: EventName<IgcGridComponentEventMap["rowEditDone"]>;
    onRowEditExit: EventName<IgcGridComponentEventMap["rowEditExit"]>;
    onColumnInit: EventName<IgcGridComponentEventMap["columnInit"]>;
    onColumnsAutogenerated: EventName<IgcGridComponentEventMap["columnsAutogenerated"]>;
    onSorting: EventName<IgcGridComponentEventMap["sorting"]>;
    onSortingDone: EventName<IgcGridComponentEventMap["sortingDone"]>;
    onFiltering: EventName<IgcGridComponentEventMap["filtering"]>;
    onFilteringDone: EventName<IgcGridComponentEventMap["filteringDone"]>;
    onRowAdded: EventName<IgcGridComponentEventMap["rowAdded"]>;
    onRowDeleted: EventName<IgcGridComponentEventMap["rowDeleted"]>;
    onRowDelete: EventName<IgcGridComponentEventMap["rowDelete"]>;
    onRowAdd: EventName<IgcGridComponentEventMap["rowAdd"]>;
    onColumnResized: EventName<IgcGridComponentEventMap["columnResized"]>;
    onContextMenu: EventName<IgcGridComponentEventMap["contextMenu"]>;
    onDoubleClick: EventName<IgcGridComponentEventMap["doubleClick"]>;
    onColumnVisibilityChanging: EventName<IgcGridComponentEventMap["columnVisibilityChanging"]>;
    onColumnVisibilityChanged: EventName<IgcGridComponentEventMap["columnVisibilityChanged"]>;
    onColumnMovingStart: EventName<IgcGridComponentEventMap["columnMovingStart"]>;
    onColumnMoving: EventName<IgcGridComponentEventMap["columnMoving"]>;
    onColumnMovingEnd: EventName<IgcGridComponentEventMap["columnMovingEnd"]>;
    onGridKeydown: EventName<IgcGridComponentEventMap["gridKeydown"]>;
    onRowDragStart: EventName<IgcGridComponentEventMap["rowDragStart"]>;
    onRowDragEnd: EventName<IgcGridComponentEventMap["rowDragEnd"]>;
    onGridCopy: EventName<IgcGridComponentEventMap["gridCopy"]>;
    onExpansionStatesChange: EventName<IgcGridComponentEventMap["expansionStatesChange"]>;
    onSelectedRowsChange: EventName<IgcGridComponentEventMap["selectedRowsChange"]>;
    onRowToggle: EventName<IgcGridComponentEventMap["rowToggle"]>;
    onRowPinning: EventName<IgcGridComponentEventMap["rowPinning"]>;
    onRowPinned: EventName<IgcGridComponentEventMap["rowPinned"]>;
    onActiveNodeChange: EventName<IgcGridComponentEventMap["activeNodeChange"]>;
    onSortingExpressionsChange: EventName<IgcGridComponentEventMap["sortingExpressionsChange"]>;
    onToolbarExporting: EventName<IgcGridComponentEventMap["toolbarExporting"]>;
    onRangeSelected: EventName<IgcGridComponentEventMap["rangeSelected"]>;
    onRendered: EventName<IgcGridComponentEventMap["rendered"]>;
    onDataChanging: EventName<IgcGridComponentEventMap["dataChanging"]>;
    onDataChanged: EventName<IgcGridComponentEventMap["dataChanged"]>;
}, {
    dropAreaTemplate: string;
    detailTemplate: string;
    groupByRowSelectorTemplate: string;
    groupRowTemplate: string;
    emptyGridTemplate: string;
    addRowEmptyTemplate: string;
    loadingGridTemplate: string;
    dragGhostCustomTemplate: string;
    rowEditTextTemplate: string;
    rowAddTextTemplate: string;
    rowEditActionsTemplate: string;
    rowExpandedIndicatorTemplate: string;
    rowCollapsedIndicatorTemplate: string;
    headerExpandedIndicatorTemplate: string;
    headerCollapsedIndicatorTemplate: string;
    excelStyleHeaderIconTemplate: string;
    sortAscendingHeaderIconTemplate: string;
    sortDescendingHeaderIconTemplate: string;
    sortHeaderIconTemplate: string;
    headSelectorTemplate: string;
    rowSelectorTemplate: string;
    dragIndicatorIconTemplate: string;
}>;
export type IgrGrid = Component;
/** @deprecated Module register is no longer needed and can be removed */
export declare const IgrGridModule: typeof Component;
