import { IgcHierarchicalGridComponent as Component } from 'igniteui-webcomponents-grids/grids/index.js';
import type { IgcHierarchicalGridComponentEventMap } from 'igniteui-webcomponents-grids/grids/index.js';
import { type EventName } from '../react-props.js';
/**
 * Hierarchical grid
 * @fires dataPreLoad - Emitted when a new chunk of data is loaded from virtualization.
 * @fires filteringExpressionsTreeChange - Emitted after filtering is performed.
 * @fires advancedFilteringExpressionsTreeChange - Emitted after advanced filtering is performed.
 * @fires gridScroll - Emitted when grid is scrolled horizontally/vertically.
 * @fires cellClick - Emitted when a cell is clicked.
 * @fires rowClick - Emitted when a row is clicked.
 * @fires formGroupCreated - Emitted when formGroup is created on edit of row/cell.
 * @fires validationStatusChange - Emitted when grid's validation status changes.
 * @fires selected - Emitted when a cell is selected.
 * @fires rowSelectionChanging - Emitted when `IgxGridRowComponent` is selected.
 * @fires columnSelectionChanging - Emitted when `IgxColumnComponent` is selected.
 * @fires columnPin - Emitted before `IgxColumnComponent` is pinned.
 * @fires columnPinned - Emitted after `IgxColumnComponent` is pinned.
 * @fires cellEditEnter - Emitted when cell enters edit mode.
 * @fires cellEditExit - Emitted when cell exits edit mode.
 * @fires cellEdit - Emitted when cell has been edited.
 * @fires cellEditDone - Emitted after cell has been edited and editing has been committed.
 * @fires rowEditEnter - Emitted when a row enters edit mode.
 * @fires rowEdit - Emitted when exiting edit mode for a row.
 * @fires rowEditDone - Emitted after exiting edit mode for a row and editing has been committed.
 * @fires rowEditExit - Emitted when row editing is canceled.
 * @fires columnInit - Emitted when a column is initialized.
 * @fires columnsAutogenerated -
 * @fires sorting - Emitted before sorting expressions are applied.
 * @fires sortingDone - Emitted after sorting is completed.
 * @fires filtering - Emitted before filtering expressions are applied.
 * @fires filteringDone - Emitted after filtering is performed through the UI.
 * @fires rowAdded - Emitted when a row is added.
 * @fires rowDeleted - Emitted when a row is deleted.
 * @fires rowDelete - Emmited when deleting a row.
 * @fires rowAdd - Emmited just before the newly added row is commited.
 * @fires columnResized - Emitted after column is resized.
 * @fires contextMenu - Emitted when a cell or row is right clicked.
 * @fires doubleClick - Emitted when a cell is double clicked.
 * @fires columnVisibilityChanging - Emitted before column visibility is changed.
 * @fires columnVisibilityChanged - Emitted after column visibility is changed.
 * @fires columnMovingStart - Emitted when column moving starts.
 * @fires columnMoving - Emitted during the column moving operation.
 * @fires columnMovingEnd - Emitted when column moving ends.
 * @fires gridKeydown - Emitted when keydown is triggered over element inside grid's body.
 * @fires rowDragStart - Emitted when start dragging a row.
 * @fires rowDragEnd - Emitted when dropping a row.
 * @fires gridCopy - Emitted when a copy operation is executed.
 * @fires expansionStatesChange - Emitted when the rows are expanded or collapsed.
 * @fires selectedRowsChange - Emitted when the rows are selected or deselected.
 * @fires rowToggle - Emitted when the expanded state of a row gets changed.
 * @fires rowPinning - Emitted when the pinned state of a row is changed.
 * @fires rowPinned - Emitted when the pinned state of a row is changed.
 * @fires activeNodeChange - Emitted when the active node is changed.
 * @fires sortingExpressionsChange - Emitted before sorting is performed.
 * @fires toolbarExporting - Emitted when an export process is initiated by the user.
 * @fires rangeSelected - Emitted when making a range selection.
 * @fires rendered - Emitted after the ngAfterViewInit hook. At this point the grid exists in the DOM
 * @fires dataChanging - Emitted before the grid's data view is changed because of a data operation, rebinding, etc.
 * @fires dataChanged - Emitted after the grid's data view is changed because of a data operation, rebinding, etc.
 */
export declare const IgrHierarchicalGrid: import("../react-props.js").ReactWebComponent<Component, {
    onDataPreLoad: EventName<IgcHierarchicalGridComponentEventMap["dataPreLoad"]>;
    onFilteringExpressionsTreeChange: EventName<IgcHierarchicalGridComponentEventMap["filteringExpressionsTreeChange"]>;
    onAdvancedFilteringExpressionsTreeChange: EventName<IgcHierarchicalGridComponentEventMap["advancedFilteringExpressionsTreeChange"]>;
    onGridScroll: EventName<IgcHierarchicalGridComponentEventMap["gridScroll"]>;
    onCellClick: EventName<IgcHierarchicalGridComponentEventMap["cellClick"]>;
    onRowClick: EventName<IgcHierarchicalGridComponentEventMap["rowClick"]>;
    onFormGroupCreated: EventName<IgcHierarchicalGridComponentEventMap["formGroupCreated"]>;
    onValidationStatusChange: EventName<IgcHierarchicalGridComponentEventMap["validationStatusChange"]>;
    onSelected: EventName<IgcHierarchicalGridComponentEventMap["selected"]>;
    onRowSelectionChanging: EventName<IgcHierarchicalGridComponentEventMap["rowSelectionChanging"]>;
    onColumnSelectionChanging: EventName<IgcHierarchicalGridComponentEventMap["columnSelectionChanging"]>;
    onColumnPin: EventName<IgcHierarchicalGridComponentEventMap["columnPin"]>;
    onColumnPinned: EventName<IgcHierarchicalGridComponentEventMap["columnPinned"]>;
    onCellEditEnter: EventName<IgcHierarchicalGridComponentEventMap["cellEditEnter"]>;
    onCellEditExit: EventName<IgcHierarchicalGridComponentEventMap["cellEditExit"]>;
    onCellEdit: EventName<IgcHierarchicalGridComponentEventMap["cellEdit"]>;
    onCellEditDone: EventName<IgcHierarchicalGridComponentEventMap["cellEditDone"]>;
    onRowEditEnter: EventName<IgcHierarchicalGridComponentEventMap["rowEditEnter"]>;
    onRowEdit: EventName<IgcHierarchicalGridComponentEventMap["rowEdit"]>;
    onRowEditDone: EventName<IgcHierarchicalGridComponentEventMap["rowEditDone"]>;
    onRowEditExit: EventName<IgcHierarchicalGridComponentEventMap["rowEditExit"]>;
    onColumnInit: EventName<IgcHierarchicalGridComponentEventMap["columnInit"]>;
    onColumnsAutogenerated: EventName<IgcHierarchicalGridComponentEventMap["columnsAutogenerated"]>;
    onSorting: EventName<IgcHierarchicalGridComponentEventMap["sorting"]>;
    onSortingDone: EventName<IgcHierarchicalGridComponentEventMap["sortingDone"]>;
    onFiltering: EventName<IgcHierarchicalGridComponentEventMap["filtering"]>;
    onFilteringDone: EventName<IgcHierarchicalGridComponentEventMap["filteringDone"]>;
    onRowAdded: EventName<IgcHierarchicalGridComponentEventMap["rowAdded"]>;
    onRowDeleted: EventName<IgcHierarchicalGridComponentEventMap["rowDeleted"]>;
    onRowDelete: EventName<IgcHierarchicalGridComponentEventMap["rowDelete"]>;
    onRowAdd: EventName<IgcHierarchicalGridComponentEventMap["rowAdd"]>;
    onColumnResized: EventName<IgcHierarchicalGridComponentEventMap["columnResized"]>;
    onContextMenu: EventName<IgcHierarchicalGridComponentEventMap["contextMenu"]>;
    onDoubleClick: EventName<IgcHierarchicalGridComponentEventMap["doubleClick"]>;
    onColumnVisibilityChanging: EventName<IgcHierarchicalGridComponentEventMap["columnVisibilityChanging"]>;
    onColumnVisibilityChanged: EventName<IgcHierarchicalGridComponentEventMap["columnVisibilityChanged"]>;
    onColumnMovingStart: EventName<IgcHierarchicalGridComponentEventMap["columnMovingStart"]>;
    onColumnMoving: EventName<IgcHierarchicalGridComponentEventMap["columnMoving"]>;
    onColumnMovingEnd: EventName<IgcHierarchicalGridComponentEventMap["columnMovingEnd"]>;
    onGridKeydown: EventName<IgcHierarchicalGridComponentEventMap["gridKeydown"]>;
    onRowDragStart: EventName<IgcHierarchicalGridComponentEventMap["rowDragStart"]>;
    onRowDragEnd: EventName<IgcHierarchicalGridComponentEventMap["rowDragEnd"]>;
    onGridCopy: EventName<IgcHierarchicalGridComponentEventMap["gridCopy"]>;
    onExpansionStatesChange: EventName<IgcHierarchicalGridComponentEventMap["expansionStatesChange"]>;
    onSelectedRowsChange: EventName<IgcHierarchicalGridComponentEventMap["selectedRowsChange"]>;
    onRowToggle: EventName<IgcHierarchicalGridComponentEventMap["rowToggle"]>;
    onRowPinning: EventName<IgcHierarchicalGridComponentEventMap["rowPinning"]>;
    onRowPinned: EventName<IgcHierarchicalGridComponentEventMap["rowPinned"]>;
    onActiveNodeChange: EventName<IgcHierarchicalGridComponentEventMap["activeNodeChange"]>;
    onSortingExpressionsChange: EventName<IgcHierarchicalGridComponentEventMap["sortingExpressionsChange"]>;
    onToolbarExporting: EventName<IgcHierarchicalGridComponentEventMap["toolbarExporting"]>;
    onRangeSelected: EventName<IgcHierarchicalGridComponentEventMap["rangeSelected"]>;
    onRendered: EventName<IgcHierarchicalGridComponentEventMap["rendered"]>;
    onDataChanging: EventName<IgcHierarchicalGridComponentEventMap["dataChanging"]>;
    onDataChanged: EventName<IgcHierarchicalGridComponentEventMap["dataChanged"]>;
}, {
    emptyGridTemplate: string;
    addRowEmptyTemplate: string;
    loadingGridTemplate: string;
    dragGhostCustomTemplate: string;
    rowEditTextTemplate: string;
    rowAddTextTemplate: string;
    rowEditActionsTemplate: string;
    rowExpandedIndicatorTemplate: string;
    rowCollapsedIndicatorTemplate: string;
    headerExpandedIndicatorTemplate: string;
    headerCollapsedIndicatorTemplate: string;
    excelStyleHeaderIconTemplate: string;
    sortAscendingHeaderIconTemplate: string;
    sortDescendingHeaderIconTemplate: string;
    sortHeaderIconTemplate: string;
    headSelectorTemplate: string;
    rowSelectorTemplate: string;
    dragIndicatorIconTemplate: string;
}>;
export type IgrHierarchicalGrid = Component;
/** @deprecated Module register is no longer needed and can be removed */
export declare const IgrHierarchicalGridModule: typeof Component;
