import { IgcPivotGridComponent as Component } from 'igniteui-webcomponents-grids/grids/index.js';
import type { IgcPivotGridComponentEventMap } from 'igniteui-webcomponents-grids/grids/index.js';
import { type EventName } from '../react-props.js';
/**
 * Pivot Grid provides a way to present and manipulate data in a pivot table view.
 * @fires dimensionsChange - Emitted when the dimension collection is changed via the grid chip area.
 * @fires pivotConfigurationChange - Emitted when any of the pivotConfiguration properties is changed via the grid chip area.
 * @fires dimensionInit - Emitted when the dimension is initialized.
 * @fires valueInit - Emitted when the value is initialized.
 * @fires dimensionsSortingExpressionsChange - Emitted when a dimension is sorted.
 * @fires valuesChange - Emitted when the values collection is changed via the grid chip area.
 * @fires filteringExpressionsTreeChange - Emitted after filtering is performed.
 * @fires advancedFilteringExpressionsTreeChange - Emitted after advanced filtering is performed.
 * @fires gridScroll - Emitted when grid is scrolled horizontally/vertically.
 * @fires cellClick - Emitted when a cell is clicked.
 * @fires rowClick - Emitted when a row is clicked.
 * @fires formGroupCreated - Emitted when formGroup is created on edit of row/cell.
 * @fires validationStatusChange - Emitted when grid's validation status changes.
 * @fires selected - Emitted when a cell is selected.
 * @fires rowSelectionChanging - Emitted when `IgxGridRowComponent` is selected.
 * @fires columnSelectionChanging - Emitted when `IgxColumnComponent` is selected.
 * @fires columnPin - Emitted before `IgxColumnComponent` is pinned.
 * @fires columnPinned - Emitted after `IgxColumnComponent` is pinned.
 * @fires cellEditEnter - Emitted when cell enters edit mode.
 * @fires cellEditExit - Emitted when cell exits edit mode.
 * @fires cellEdit - Emitted when cell has been edited.
 * @fires cellEditDone - Emitted after cell has been edited and editing has been committed.
 * @fires rowEditEnter - Emitted when a row enters edit mode.
 * @fires rowEdit - Emitted when exiting edit mode for a row.
 * @fires rowEditDone - Emitted after exiting edit mode for a row and editing has been committed.
 * @fires rowEditExit - Emitted when row editing is canceled.
 * @fires columnInit - Emitted when a column is initialized.
 * @fires columnsAutogenerated -
 * @fires sorting - Emitted before sorting expressions are applied.
 * @fires sortingDone - Emitted after sorting is completed.
 * @fires filtering - Emitted before filtering expressions are applied.
 * @fires filteringDone - Emitted after filtering is performed through the UI.
 * @fires rowAdded - Emitted when a row is added.
 * @fires rowDeleted - Emitted when a row is deleted.
 * @fires rowDelete - Emmited when deleting a row.
 * @fires rowAdd - Emmited just before the newly added row is commited.
 * @fires columnResized - Emitted after column is resized.
 * @fires contextMenu - Emitted when a cell or row is right clicked.
 * @fires doubleClick - Emitted when a cell is double clicked.
 * @fires columnVisibilityChanging - Emitted before column visibility is changed.
 * @fires columnVisibilityChanged - Emitted after column visibility is changed.
 * @fires columnMovingStart - Emitted when column moving starts.
 * @fires columnMoving - Emitted during the column moving operation.
 * @fires columnMovingEnd - Emitted when column moving ends.
 * @fires gridKeydown - Emitted when keydown is triggered over element inside grid's body.
 * @fires rowDragStart - Emitted when start dragging a row.
 * @fires rowDragEnd - Emitted when dropping a row.
 * @fires gridCopy - Emitted when a copy operation is executed.
 * @fires expansionStatesChange - Emitted when the rows are expanded or collapsed.
 * @fires selectedRowsChange - Emitted when the rows are selected or deselected.
 * @fires rowToggle - Emitted when the expanded state of a row gets changed.
 * @fires rowPinning - Emitted when the pinned state of a row is changed.
 * @fires rowPinned - Emitted when the pinned state of a row is changed.
 * @fires activeNodeChange - Emitted when the active node is changed.
 * @fires sortingExpressionsChange - Emitted before sorting is performed.
 * @fires toolbarExporting - Emitted when an export process is initiated by the user.
 * @fires rangeSelected - Emitted when making a range selection.
 * @fires rendered - Emitted after the ngAfterViewInit hook. At this point the grid exists in the DOM
 * @fires dataChanging - Emitted before the grid's data view is changed because of a data operation, rebinding, etc.
 * @fires dataChanged - Emitted after the grid's data view is changed because of a data operation, rebinding, etc.
 */
export declare const IgrPivotGrid: import("../react-props.js").ReactWebComponent<Component, {
    onDimensionsChange: EventName<IgcPivotGridComponentEventMap["dimensionsChange"]>;
    onPivotConfigurationChange: EventName<IgcPivotGridComponentEventMap["pivotConfigurationChange"]>;
    onDimensionInit: EventName<IgcPivotGridComponentEventMap["dimensionInit"]>;
    onValueInit: EventName<IgcPivotGridComponentEventMap["valueInit"]>;
    onDimensionsSortingExpressionsChange: EventName<IgcPivotGridComponentEventMap["dimensionsSortingExpressionsChange"]>;
    onValuesChange: EventName<IgcPivotGridComponentEventMap["valuesChange"]>;
    onFilteringExpressionsTreeChange: EventName<IgcPivotGridComponentEventMap["filteringExpressionsTreeChange"]>;
    onAdvancedFilteringExpressionsTreeChange: EventName<IgcPivotGridComponentEventMap["advancedFilteringExpressionsTreeChange"]>;
    onGridScroll: EventName<IgcPivotGridComponentEventMap["gridScroll"]>;
    onCellClick: EventName<IgcPivotGridComponentEventMap["cellClick"]>;
    onRowClick: EventName<IgcPivotGridComponentEventMap["rowClick"]>;
    onFormGroupCreated: EventName<IgcPivotGridComponentEventMap["formGroupCreated"]>;
    onValidationStatusChange: EventName<IgcPivotGridComponentEventMap["validationStatusChange"]>;
    onSelected: EventName<IgcPivotGridComponentEventMap["selected"]>;
    onRowSelectionChanging: EventName<IgcPivotGridComponentEventMap["rowSelectionChanging"]>;
    onColumnSelectionChanging: EventName<IgcPivotGridComponentEventMap["columnSelectionChanging"]>;
    onColumnPin: EventName<IgcPivotGridComponentEventMap["columnPin"]>;
    onColumnPinned: EventName<IgcPivotGridComponentEventMap["columnPinned"]>;
    onCellEditEnter: EventName<IgcPivotGridComponentEventMap["cellEditEnter"]>;
    onCellEditExit: EventName<IgcPivotGridComponentEventMap["cellEditExit"]>;
    onCellEdit: EventName<IgcPivotGridComponentEventMap["cellEdit"]>;
    onCellEditDone: EventName<IgcPivotGridComponentEventMap["cellEditDone"]>;
    onRowEditEnter: EventName<IgcPivotGridComponentEventMap["rowEditEnter"]>;
    onRowEdit: EventName<IgcPivotGridComponentEventMap["rowEdit"]>;
    onRowEditDone: EventName<IgcPivotGridComponentEventMap["rowEditDone"]>;
    onRowEditExit: EventName<IgcPivotGridComponentEventMap["rowEditExit"]>;
    onColumnInit: EventName<IgcPivotGridComponentEventMap["columnInit"]>;
    onColumnsAutogenerated: EventName<IgcPivotGridComponentEventMap["columnsAutogenerated"]>;
    onSorting: EventName<IgcPivotGridComponentEventMap["sorting"]>;
    onSortingDone: EventName<IgcPivotGridComponentEventMap["sortingDone"]>;
    onFiltering: EventName<IgcPivotGridComponentEventMap["filtering"]>;
    onFilteringDone: EventName<IgcPivotGridComponentEventMap["filteringDone"]>;
    onRowAdded: EventName<IgcPivotGridComponentEventMap["rowAdded"]>;
    onRowDeleted: EventName<IgcPivotGridComponentEventMap["rowDeleted"]>;
    onRowDelete: EventName<IgcPivotGridComponentEventMap["rowDelete"]>;
    onRowAdd: EventName<IgcPivotGridComponentEventMap["rowAdd"]>;
    onColumnResized: EventName<IgcPivotGridComponentEventMap["columnResized"]>;
    onContextMenu: EventName<IgcPivotGridComponentEventMap["contextMenu"]>;
    onDoubleClick: EventName<IgcPivotGridComponentEventMap["doubleClick"]>;
    onColumnVisibilityChanging: EventName<IgcPivotGridComponentEventMap["columnVisibilityChanging"]>;
    onColumnVisibilityChanged: EventName<IgcPivotGridComponentEventMap["columnVisibilityChanged"]>;
    onColumnMovingStart: EventName<IgcPivotGridComponentEventMap["columnMovingStart"]>;
    onColumnMoving: EventName<IgcPivotGridComponentEventMap["columnMoving"]>;
    onColumnMovingEnd: EventName<IgcPivotGridComponentEventMap["columnMovingEnd"]>;
    onGridKeydown: EventName<IgcPivotGridComponentEventMap["gridKeydown"]>;
    onRowDragStart: EventName<IgcPivotGridComponentEventMap["rowDragStart"]>;
    onRowDragEnd: EventName<IgcPivotGridComponentEventMap["rowDragEnd"]>;
    onGridCopy: EventName<IgcPivotGridComponentEventMap["gridCopy"]>;
    onExpansionStatesChange: EventName<IgcPivotGridComponentEventMap["expansionStatesChange"]>;
    onSelectedRowsChange: EventName<IgcPivotGridComponentEventMap["selectedRowsChange"]>;
    onRowToggle: EventName<IgcPivotGridComponentEventMap["rowToggle"]>;
    onRowPinning: EventName<IgcPivotGridComponentEventMap["rowPinning"]>;
    onRowPinned: EventName<IgcPivotGridComponentEventMap["rowPinned"]>;
    onActiveNodeChange: EventName<IgcPivotGridComponentEventMap["activeNodeChange"]>;
    onSortingExpressionsChange: EventName<IgcPivotGridComponentEventMap["sortingExpressionsChange"]>;
    onToolbarExporting: EventName<IgcPivotGridComponentEventMap["toolbarExporting"]>;
    onRangeSelected: EventName<IgcPivotGridComponentEventMap["rangeSelected"]>;
    onRendered: EventName<IgcPivotGridComponentEventMap["rendered"]>;
    onDataChanging: EventName<IgcPivotGridComponentEventMap["dataChanging"]>;
    onDataChanged: EventName<IgcPivotGridComponentEventMap["dataChanged"]>;
}, {
    valueChipTemplate: string;
    rowDimensionHeaderTemplate: string;
    emptyPivotGridTemplate: string;
    emptyGridTemplate: string;
    addRowEmptyTemplate: string;
    loadingGridTemplate: string;
    dragGhostCustomTemplate: string;
    rowEditTextTemplate: string;
    rowAddTextTemplate: string;
    rowEditActionsTemplate: string;
    rowExpandedIndicatorTemplate: string;
    rowCollapsedIndicatorTemplate: string;
    headerExpandedIndicatorTemplate: string;
    headerCollapsedIndicatorTemplate: string;
    excelStyleHeaderIconTemplate: string;
    sortAscendingHeaderIconTemplate: string;
    sortDescendingHeaderIconTemplate: string;
    sortHeaderIconTemplate: string;
    headSelectorTemplate: string;
    rowSelectorTemplate: string;
    dragIndicatorIconTemplate: string;
}>;
export type IgrPivotGrid = Component;
/** @deprecated Module register is no longer needed and can be removed */
export declare const IgrPivotGridModule: typeof Component;
