import { IgcRowIslandComponent as Component } from 'igniteui-webcomponents-grids/grids/index.js';
import type { IgcRowIslandComponentEventMap } from 'igniteui-webcomponents-grids/grids/index.js';
import { type EventName } from '../react-props.js';
/**
 * Row island
 * @fires gridCreated - Event emitted when a grid is being created based on this row island.
 * @fires gridInitialized - Emitted after a grid is being initialized for this row island.  The emitting is done in `ngAfterViewInit`.
 * @fires dataPreLoad - Emitted when a new chunk of data is loaded from virtualization.
 * @fires filteringExpressionsTreeChange - Emitted after filtering is performed.
 * @fires advancedFilteringExpressionsTreeChange - Emitted after advanced filtering is performed.
 * @fires gridScroll - Emitted when grid is scrolled horizontally/vertically.
 * @fires cellClick - Emitted when a cell is clicked.
 * @fires rowClick - Emitted when a row is clicked.
 * @fires formGroupCreated - Emitted when formGroup is created on edit of row/cell.
 * @fires validationStatusChange - Emitted when grid's validation status changes.
 * @fires selected - Emitted when a cell is selected.
 * @fires rowSelectionChanging - Emitted when `IgxGridRowComponent` is selected.
 * @fires columnSelectionChanging - Emitted when `IgxColumnComponent` is selected.
 * @fires columnPin - Emitted before `IgxColumnComponent` is pinned.
 * @fires columnPinned - Emitted after `IgxColumnComponent` is pinned.
 * @fires cellEditEnter - Emitted when cell enters edit mode.
 * @fires cellEditExit - Emitted when cell exits edit mode.
 * @fires cellEdit - Emitted when cell has been edited.
 * @fires cellEditDone - Emitted after cell has been edited and editing has been committed.
 * @fires rowEditEnter - Emitted when a row enters edit mode.
 * @fires rowEdit - Emitted when exiting edit mode for a row.
 * @fires rowEditDone - Emitted after exiting edit mode for a row and editing has been committed.
 * @fires rowEditExit - Emitted when row editing is canceled.
 * @fires columnInit - Emitted when a column is initialized.
 * @fires columnsAutogenerated -
 * @fires sorting - Emitted before sorting expressions are applied.
 * @fires sortingDone - Emitted after sorting is completed.
 * @fires filtering - Emitted before filtering expressions are applied.
 * @fires filteringDone - Emitted after filtering is performed through the UI.
 * @fires rowAdded - Emitted when a row is added.
 * @fires rowDeleted - Emitted when a row is deleted.
 * @fires rowDelete - Emmited when deleting a row.
 * @fires rowAdd - Emmited just before the newly added row is commited.
 * @fires columnResized - Emitted after column is resized.
 * @fires contextMenu - Emitted when a cell or row is right clicked.
 * @fires doubleClick - Emitted when a cell is double clicked.
 * @fires columnVisibilityChanging - Emitted before column visibility is changed.
 * @fires columnVisibilityChanged - Emitted after column visibility is changed.
 * @fires columnMovingStart - Emitted when column moving starts.
 * @fires columnMoving - Emitted during the column moving operation.
 * @fires columnMovingEnd - Emitted when column moving ends.
 * @fires gridKeydown - Emitted when keydown is triggered over element inside grid's body.
 * @fires rowDragStart - Emitted when start dragging a row.
 * @fires rowDragEnd - Emitted when dropping a row.
 * @fires gridCopy - Emitted when a copy operation is executed.
 * @fires expansionStatesChange - Emitted when the rows are expanded or collapsed.
 * @fires selectedRowsChange - Emitted when the rows are selected or deselected.
 * @fires rowToggle - Emitted when the expanded state of a row gets changed.
 * @fires rowPinning - Emitted when the pinned state of a row is changed.
 * @fires rowPinned - Emitted when the pinned state of a row is changed.
 * @fires activeNodeChange - Emitted when the active node is changed.
 * @fires sortingExpressionsChange - Emitted before sorting is performed.
 * @fires toolbarExporting - Emitted when an export process is initiated by the user.
 * @fires rangeSelected - Emitted when making a range selection.
 * @fires rendered - Emitted after the ngAfterViewInit hook. At this point the grid exists in the DOM
 * @fires dataChanging - Emitted before the grid's data view is changed because of a data operation, rebinding, etc.
 * @fires dataChanged - Emitted after the grid's data view is changed because of a data operation, rebinding, etc.
 */
export declare const IgrRowIsland: import("../react-props.js").ReactWebComponent<Component, {
    onGridCreated: EventName<IgcRowIslandComponentEventMap["gridCreated"]>;
    onGridInitialized: EventName<IgcRowIslandComponentEventMap["gridInitialized"]>;
    onDataPreLoad: EventName<IgcRowIslandComponentEventMap["dataPreLoad"]>;
    onFilteringExpressionsTreeChange: EventName<IgcRowIslandComponentEventMap["filteringExpressionsTreeChange"]>;
    onAdvancedFilteringExpressionsTreeChange: EventName<IgcRowIslandComponentEventMap["advancedFilteringExpressionsTreeChange"]>;
    onGridScroll: EventName<IgcRowIslandComponentEventMap["gridScroll"]>;
    onCellClick: EventName<IgcRowIslandComponentEventMap["cellClick"]>;
    onRowClick: EventName<IgcRowIslandComponentEventMap["rowClick"]>;
    onFormGroupCreated: EventName<IgcRowIslandComponentEventMap["formGroupCreated"]>;
    onValidationStatusChange: EventName<IgcRowIslandComponentEventMap["validationStatusChange"]>;
    onSelected: EventName<IgcRowIslandComponentEventMap["selected"]>;
    onRowSelectionChanging: EventName<IgcRowIslandComponentEventMap["rowSelectionChanging"]>;
    onColumnSelectionChanging: EventName<IgcRowIslandComponentEventMap["columnSelectionChanging"]>;
    onColumnPin: EventName<IgcRowIslandComponentEventMap["columnPin"]>;
    onColumnPinned: EventName<IgcRowIslandComponentEventMap["columnPinned"]>;
    onCellEditEnter: EventName<IgcRowIslandComponentEventMap["cellEditEnter"]>;
    onCellEditExit: EventName<IgcRowIslandComponentEventMap["cellEditExit"]>;
    onCellEdit: EventName<IgcRowIslandComponentEventMap["cellEdit"]>;
    onCellEditDone: EventName<IgcRowIslandComponentEventMap["cellEditDone"]>;
    onRowEditEnter: EventName<IgcRowIslandComponentEventMap["rowEditEnter"]>;
    onRowEdit: EventName<IgcRowIslandComponentEventMap["rowEdit"]>;
    onRowEditDone: EventName<IgcRowIslandComponentEventMap["rowEditDone"]>;
    onRowEditExit: EventName<IgcRowIslandComponentEventMap["rowEditExit"]>;
    onColumnInit: EventName<IgcRowIslandComponentEventMap["columnInit"]>;
    onColumnsAutogenerated: EventName<IgcRowIslandComponentEventMap["columnsAutogenerated"]>;
    onSorting: EventName<IgcRowIslandComponentEventMap["sorting"]>;
    onSortingDone: EventName<IgcRowIslandComponentEventMap["sortingDone"]>;
    onFiltering: EventName<IgcRowIslandComponentEventMap["filtering"]>;
    onFilteringDone: EventName<IgcRowIslandComponentEventMap["filteringDone"]>;
    onRowAdded: EventName<IgcRowIslandComponentEventMap["rowAdded"]>;
    onRowDeleted: EventName<IgcRowIslandComponentEventMap["rowDeleted"]>;
    onRowDelete: EventName<IgcRowIslandComponentEventMap["rowDelete"]>;
    onRowAdd: EventName<IgcRowIslandComponentEventMap["rowAdd"]>;
    onColumnResized: EventName<IgcRowIslandComponentEventMap["columnResized"]>;
    onContextMenu: EventName<IgcRowIslandComponentEventMap["contextMenu"]>;
    onDoubleClick: EventName<IgcRowIslandComponentEventMap["doubleClick"]>;
    onColumnVisibilityChanging: EventName<IgcRowIslandComponentEventMap["columnVisibilityChanging"]>;
    onColumnVisibilityChanged: EventName<IgcRowIslandComponentEventMap["columnVisibilityChanged"]>;
    onColumnMovingStart: EventName<IgcRowIslandComponentEventMap["columnMovingStart"]>;
    onColumnMoving: EventName<IgcRowIslandComponentEventMap["columnMoving"]>;
    onColumnMovingEnd: EventName<IgcRowIslandComponentEventMap["columnMovingEnd"]>;
    onGridKeydown: EventName<IgcRowIslandComponentEventMap["gridKeydown"]>;
    onRowDragStart: EventName<IgcRowIslandComponentEventMap["rowDragStart"]>;
    onRowDragEnd: EventName<IgcRowIslandComponentEventMap["rowDragEnd"]>;
    onGridCopy: EventName<IgcRowIslandComponentEventMap["gridCopy"]>;
    onExpansionStatesChange: EventName<IgcRowIslandComponentEventMap["expansionStatesChange"]>;
    onSelectedRowsChange: EventName<IgcRowIslandComponentEventMap["selectedRowsChange"]>;
    onRowToggle: EventName<IgcRowIslandComponentEventMap["rowToggle"]>;
    onRowPinning: EventName<IgcRowIslandComponentEventMap["rowPinning"]>;
    onRowPinned: EventName<IgcRowIslandComponentEventMap["rowPinned"]>;
    onActiveNodeChange: EventName<IgcRowIslandComponentEventMap["activeNodeChange"]>;
    onSortingExpressionsChange: EventName<IgcRowIslandComponentEventMap["sortingExpressionsChange"]>;
    onToolbarExporting: EventName<IgcRowIslandComponentEventMap["toolbarExporting"]>;
    onRangeSelected: EventName<IgcRowIslandComponentEventMap["rangeSelected"]>;
    onRendered: EventName<IgcRowIslandComponentEventMap["rendered"]>;
    onDataChanging: EventName<IgcRowIslandComponentEventMap["dataChanging"]>;
    onDataChanged: EventName<IgcRowIslandComponentEventMap["dataChanged"]>;
}, {
    toolbarTemplate: string;
    paginatorTemplate: string;
    emptyGridTemplate: string;
    addRowEmptyTemplate: string;
    loadingGridTemplate: string;
    dragGhostCustomTemplate: string;
    rowEditTextTemplate: string;
    rowAddTextTemplate: string;
    rowEditActionsTemplate: string;
    rowExpandedIndicatorTemplate: string;
    rowCollapsedIndicatorTemplate: string;
    headerExpandedIndicatorTemplate: string;
    headerCollapsedIndicatorTemplate: string;
    excelStyleHeaderIconTemplate: string;
    sortAscendingHeaderIconTemplate: string;
    sortDescendingHeaderIconTemplate: string;
    sortHeaderIconTemplate: string;
    headSelectorTemplate: string;
    rowSelectorTemplate: string;
    dragIndicatorIconTemplate: string;
}>;
export type IgrRowIsland = Component;
/** @deprecated Module register is no longer needed and can be removed */
export declare const IgrRowIslandModule: typeof Component;
