import { IgcTreeGridComponent as Component } from 'igniteui-webcomponents-grids/grids/index.js';
import type { IgcTreeGridComponentEventMap } from 'igniteui-webcomponents-grids/grids/index.js';
import { type EventName } from '../react-props.js';
/**
 * **Ignite UI for Angular Tree Grid** -  [Documentation](https://www.infragistics.com/products/ignite-ui-angular/angular/components/grid/grid)   The Ignite UI Tree Grid displays and manipulates hierarchical data with consistent schema formatted as a table and  provides features such as sorting, filtering, editing, column pinning, paging, column moving and hiding.   Example:
 * @fires filteringExpressionsTreeChange - Emitted after filtering is performed.
 * @fires advancedFilteringExpressionsTreeChange - Emitted after advanced filtering is performed.
 * @fires gridScroll - Emitted when grid is scrolled horizontally/vertically.
 * @fires cellClick - Emitted when a cell is clicked.
 * @fires rowClick - Emitted when a row is clicked.
 * @fires formGroupCreated - Emitted when formGroup is created on edit of row/cell.
 * @fires validationStatusChange - Emitted when grid's validation status changes.
 * @fires selected - Emitted when a cell is selected.
 * @fires rowSelectionChanging - Emitted when `IgxGridRowComponent` is selected.
 * @fires columnSelectionChanging - Emitted when `IgxColumnComponent` is selected.
 * @fires columnPin - Emitted before `IgxColumnComponent` is pinned.
 * @fires columnPinned - Emitted after `IgxColumnComponent` is pinned.
 * @fires cellEditEnter - Emitted when cell enters edit mode.
 * @fires cellEditExit - Emitted when cell exits edit mode.
 * @fires cellEdit - Emitted when cell has been edited.
 * @fires cellEditDone - Emitted after cell has been edited and editing has been committed.
 * @fires rowEditEnter - Emitted when a row enters edit mode.
 * @fires rowEdit - Emitted when exiting edit mode for a row.
 * @fires rowEditDone - Emitted after exiting edit mode for a row and editing has been committed.
 * @fires rowEditExit - Emitted when row editing is canceled.
 * @fires columnInit - Emitted when a column is initialized.
 * @fires columnsAutogenerated -
 * @fires sorting - Emitted before sorting expressions are applied.
 * @fires sortingDone - Emitted after sorting is completed.
 * @fires filtering - Emitted before filtering expressions are applied.
 * @fires filteringDone - Emitted after filtering is performed through the UI.
 * @fires rowAdded - Emitted when a row is added.
 * @fires rowDeleted - Emitted when a row is deleted.
 * @fires rowDelete - Emmited when deleting a row.
 * @fires rowAdd - Emmited just before the newly added row is commited.
 * @fires columnResized - Emitted after column is resized.
 * @fires contextMenu - Emitted when a cell or row is right clicked.
 * @fires doubleClick - Emitted when a cell is double clicked.
 * @fires columnVisibilityChanging - Emitted before column visibility is changed.
 * @fires columnVisibilityChanged - Emitted after column visibility is changed.
 * @fires columnMovingStart - Emitted when column moving starts.
 * @fires columnMoving - Emitted during the column moving operation.
 * @fires columnMovingEnd - Emitted when column moving ends.
 * @fires gridKeydown - Emitted when keydown is triggered over element inside grid's body.
 * @fires rowDragStart - Emitted when start dragging a row.
 * @fires rowDragEnd - Emitted when dropping a row.
 * @fires gridCopy - Emitted when a copy operation is executed.
 * @fires expansionStatesChange - Emitted when the rows are expanded or collapsed.
 * @fires selectedRowsChange - Emitted when the rows are selected or deselected.
 * @fires rowToggle - Emitted when the expanded state of a row gets changed.
 * @fires rowPinning - Emitted when the pinned state of a row is changed.
 * @fires rowPinned - Emitted when the pinned state of a row is changed.
 * @fires activeNodeChange - Emitted when the active node is changed.
 * @fires sortingExpressionsChange - Emitted before sorting is performed.
 * @fires toolbarExporting - Emitted when an export process is initiated by the user.
 * @fires rangeSelected - Emitted when making a range selection.
 * @fires rendered - Emitted after the ngAfterViewInit hook. At this point the grid exists in the DOM
 * @fires dataChanging - Emitted before the grid's data view is changed because of a data operation, rebinding, etc.
 * @fires dataChanged - Emitted after the grid's data view is changed because of a data operation, rebinding, etc.
 */
export declare const IgrTreeGrid: import("../react-props.js").ReactWebComponent<Component, {
    onFilteringExpressionsTreeChange: EventName<IgcTreeGridComponentEventMap["filteringExpressionsTreeChange"]>;
    onAdvancedFilteringExpressionsTreeChange: EventName<IgcTreeGridComponentEventMap["advancedFilteringExpressionsTreeChange"]>;
    onGridScroll: EventName<IgcTreeGridComponentEventMap["gridScroll"]>;
    onCellClick: EventName<IgcTreeGridComponentEventMap["cellClick"]>;
    onRowClick: EventName<IgcTreeGridComponentEventMap["rowClick"]>;
    onFormGroupCreated: EventName<IgcTreeGridComponentEventMap["formGroupCreated"]>;
    onValidationStatusChange: EventName<IgcTreeGridComponentEventMap["validationStatusChange"]>;
    onSelected: EventName<IgcTreeGridComponentEventMap["selected"]>;
    onRowSelectionChanging: EventName<IgcTreeGridComponentEventMap["rowSelectionChanging"]>;
    onColumnSelectionChanging: EventName<IgcTreeGridComponentEventMap["columnSelectionChanging"]>;
    onColumnPin: EventName<IgcTreeGridComponentEventMap["columnPin"]>;
    onColumnPinned: EventName<IgcTreeGridComponentEventMap["columnPinned"]>;
    onCellEditEnter: EventName<IgcTreeGridComponentEventMap["cellEditEnter"]>;
    onCellEditExit: EventName<IgcTreeGridComponentEventMap["cellEditExit"]>;
    onCellEdit: EventName<IgcTreeGridComponentEventMap["cellEdit"]>;
    onCellEditDone: EventName<IgcTreeGridComponentEventMap["cellEditDone"]>;
    onRowEditEnter: EventName<IgcTreeGridComponentEventMap["rowEditEnter"]>;
    onRowEdit: EventName<IgcTreeGridComponentEventMap["rowEdit"]>;
    onRowEditDone: EventName<IgcTreeGridComponentEventMap["rowEditDone"]>;
    onRowEditExit: EventName<IgcTreeGridComponentEventMap["rowEditExit"]>;
    onColumnInit: EventName<IgcTreeGridComponentEventMap["columnInit"]>;
    onColumnsAutogenerated: EventName<IgcTreeGridComponentEventMap["columnsAutogenerated"]>;
    onSorting: EventName<IgcTreeGridComponentEventMap["sorting"]>;
    onSortingDone: EventName<IgcTreeGridComponentEventMap["sortingDone"]>;
    onFiltering: EventName<IgcTreeGridComponentEventMap["filtering"]>;
    onFilteringDone: EventName<IgcTreeGridComponentEventMap["filteringDone"]>;
    onRowAdded: EventName<IgcTreeGridComponentEventMap["rowAdded"]>;
    onRowDeleted: EventName<IgcTreeGridComponentEventMap["rowDeleted"]>;
    onRowDelete: EventName<IgcTreeGridComponentEventMap["rowDelete"]>;
    onRowAdd: EventName<IgcTreeGridComponentEventMap["rowAdd"]>;
    onColumnResized: EventName<IgcTreeGridComponentEventMap["columnResized"]>;
    onContextMenu: EventName<IgcTreeGridComponentEventMap["contextMenu"]>;
    onDoubleClick: EventName<IgcTreeGridComponentEventMap["doubleClick"]>;
    onColumnVisibilityChanging: EventName<IgcTreeGridComponentEventMap["columnVisibilityChanging"]>;
    onColumnVisibilityChanged: EventName<IgcTreeGridComponentEventMap["columnVisibilityChanged"]>;
    onColumnMovingStart: EventName<IgcTreeGridComponentEventMap["columnMovingStart"]>;
    onColumnMoving: EventName<IgcTreeGridComponentEventMap["columnMoving"]>;
    onColumnMovingEnd: EventName<IgcTreeGridComponentEventMap["columnMovingEnd"]>;
    onGridKeydown: EventName<IgcTreeGridComponentEventMap["gridKeydown"]>;
    onRowDragStart: EventName<IgcTreeGridComponentEventMap["rowDragStart"]>;
    onRowDragEnd: EventName<IgcTreeGridComponentEventMap["rowDragEnd"]>;
    onGridCopy: EventName<IgcTreeGridComponentEventMap["gridCopy"]>;
    onExpansionStatesChange: EventName<IgcTreeGridComponentEventMap["expansionStatesChange"]>;
    onSelectedRowsChange: EventName<IgcTreeGridComponentEventMap["selectedRowsChange"]>;
    onRowToggle: EventName<IgcTreeGridComponentEventMap["rowToggle"]>;
    onRowPinning: EventName<IgcTreeGridComponentEventMap["rowPinning"]>;
    onRowPinned: EventName<IgcTreeGridComponentEventMap["rowPinned"]>;
    onActiveNodeChange: EventName<IgcTreeGridComponentEventMap["activeNodeChange"]>;
    onSortingExpressionsChange: EventName<IgcTreeGridComponentEventMap["sortingExpressionsChange"]>;
    onToolbarExporting: EventName<IgcTreeGridComponentEventMap["toolbarExporting"]>;
    onRangeSelected: EventName<IgcTreeGridComponentEventMap["rangeSelected"]>;
    onRendered: EventName<IgcTreeGridComponentEventMap["rendered"]>;
    onDataChanging: EventName<IgcTreeGridComponentEventMap["dataChanging"]>;
    onDataChanged: EventName<IgcTreeGridComponentEventMap["dataChanged"]>;
}, {
    rowLoadingIndicatorTemplate: string;
    emptyGridTemplate: string;
    addRowEmptyTemplate: string;
    loadingGridTemplate: string;
    dragGhostCustomTemplate: string;
    rowEditTextTemplate: string;
    rowAddTextTemplate: string;
    rowEditActionsTemplate: string;
    rowExpandedIndicatorTemplate: string;
    rowCollapsedIndicatorTemplate: string;
    headerExpandedIndicatorTemplate: string;
    headerCollapsedIndicatorTemplate: string;
    excelStyleHeaderIconTemplate: string;
    sortAscendingHeaderIconTemplate: string;
    sortDescendingHeaderIconTemplate: string;
    sortHeaderIconTemplate: string;
    headSelectorTemplate: string;
    rowSelectorTemplate: string;
    dragIndicatorIconTemplate: string;
}>;
export type IgrTreeGrid = Component;
/** @deprecated Module register is no longer needed and can be removed */
export declare const IgrTreeGridModule: typeof Component;
